@@ -5,7 +5,10 @@ from .client_functions import batch, construct_user, construct_event, post, put
 from .experiments import create_experiment, get_experiment, get_offers_in_experiment, query_experiments
 from .products import create_product, query_products
 from .trackedusers import create_user, create_or_update_users
-from .touchpoints import create_touchpoint_on_tracked_user, get_touchpoint_on_tracked_user
+from .touchpoints import create_touchpoint_on_tracked_user, get_touchpoint_on_tracked_user, get_touchpoint
+from .parameters import create_parameter
+from .parameter_recommenders import create_parameterset_recommender
+from .product_recommenders import invoke_product_recommender
 
 
 class Configuration:
@@ -84,6 +87,9 @@ class SignalBoxClient:
         return get_touchpoint_on_tracked_user(
             self.access_token, self.base_url, tracked_user_id=tracked_user_id, touchpoint_id=touchpoint_id, version=version)
 
+    def get_touchpoint(self, touchpoint_id: str):
+        return get_touchpoint(self.access_token, self.base_url, touchpoint_id=touchpoint_id)
+
     def create_or_update_users(self, users):
         return create_or_update_users(self.access_token, self.base_url,  users)
 
@@ -105,6 +111,10 @@ class SignalBoxClient:
         else:
             raise SignalBoxException(r.text)
 
+    def create_parameter(self, common_id: str, name: str, parameter_type: str = "Numerical", description: str = None):
+        return create_parameter(self.access_token, self.base_url,
+                                common_id, name, parameter_type, description)
+
     def create_experiment(self, offer_ids: list, name: str, concurrent_offers: int = 1, segment_id: str = None):
         return create_experiment(self.access_token, self.base_url,
                                  offer_ids, name, concurrent_offers, segment_id)
@@ -118,6 +128,9 @@ class SignalBoxClient:
     def get_offers_in_experiment(self, experiment_id: str):
         return get_offers_in_experiment(self.access_token, self.base_url, experiment_id)
 
+    def invoke_product_recommender(self, recommender_id: int, common_user_id: str):
+        return invoke_product_recommender(self.access_token, self.base_url, id=recommender_id, common_user_id=common_user_id)
+
     def recommend_offer(self, experimentId: str, commonUserId: str, features: dict = None):
         json_params = {
             "commonUserId": commonUserId,
@@ -148,8 +161,8 @@ class SignalBoxClient:
         else:
             raise SignalBoxException(r.text)
 
-    def construct_event(self, commonUserId, event_id, event_type, kind, properties, timestamp=None, source_system_id=None):
-        return construct_event(commonUserId, event_id, event_type, kind, properties, timestamp, source_system_id)
+    def construct_event(self, commonUserId, event_id, event_type, kind, properties, timestamp=None, source_system_id=None, recommendationCorrelatorId: int = None):
+        return construct_event(commonUserId, event_id, event_type, kind, properties, timestamp, source_system_id, recommendationCorrelatorId)
 
     def construct_user(self, commonUserId: str, name: str = None, properties: str = None, integratedSystemId: int = None, userId: str = None):
         return construct_user(commonUserId, name=name, properties=properties, integratedSystemId=integratedSystemId, userId=userId)
